package com.wyattjmiller.plugins

import com.typesafe.config.ConfigFactory
import com.wyattjmiller.auth.JwtConfig
import io.ktor.server.application.*
import io.ktor.server.auth.*
import io.ktor.server.auth.jwt.*
import io.ktor.server.config.*

fun Application.configureAuthentication() {
    val config = HoconApplicationConfig(ConfigFactory.load())
    val tokenManager = JwtConfig(config)

    install(Authentication) {
        jwt {
            verifier(tokenManager.verifyJwtToken())
            realm = config.property("realm").getString()

            validate { jwt ->
                if (jwt.payload.getClaim("username").asString().isNotEmpty()) {
                    JWTPrincipal(jwt.payload)
                } else {
                    null
                }
            }
        }
    }


}