package com.wyattjmiller.repositories

import com.wyattjmiller.data.DatabaseManager
import com.wyattjmiller.data.DbAuthorTable
import com.wyattjmiller.entities.Author
import com.wyattjmiller.entities.AuthorDraft
import org.ktorm.dsl.delete
import org.ktorm.dsl.eq
import org.ktorm.dsl.insertAndGenerateKey
import org.ktorm.dsl.update
import org.ktorm.entity.firstOrNull
import org.ktorm.entity.sequenceOf
import org.ktorm.entity.toList
import java.time.LocalDateTime

class AuthorDao : AuthorRepository {
    private val db = DatabaseManager().database

    override fun getAllAuthors() : List<Author> {
        return db
            .sequenceOf(DbAuthorTable)
            .toList()
            .map {
                Author(it.id, it.authorName, it.user!!.id, it.createdTimestamp.toString())
            }
    }

    override fun getAuthor(id: Int) : Author {
        return db
            .sequenceOf(DbAuthorTable)
            .firstOrNull {
                it.id eq id
            }
            .let {
                Author(it!!.id, it.authorName, it.user!!.id, it.createdTimestamp.toString())
            }
    }

    override fun createAuthor(author: AuthorDraft) {
        db.insertAndGenerateKey(DbAuthorTable) {
            set(DbAuthorTable.authorName, author.authorName)
            set(DbAuthorTable.user, author.user)
            set(DbAuthorTable.createdTimestamp, LocalDateTime.now())
        } as Int
    }

    override fun updateAuthor(id: Int, author: AuthorDraft) : Boolean {
        val updatedRows = db.update(DbAuthorTable) {
            set(DbAuthorTable.authorName, author.authorName)
            set(DbAuthorTable.user, author.user)
            where {
                it.id eq id
            }
        }

        return updatedRows > 0
    }

    override fun deleteAuthor(id: Int) : Boolean {
        val deletedRows = db.delete(DbAuthorTable) {
            it.id eq id
        }

        return deletedRows > 0
    }
}